﻿(* Raima.Rdm is the system module that contains the ADO.NET data provider
   for RDM *)
open Raima.Rdm

(* EXAMPLE - SQL04 for F# using ADO.NET *)
(* When you run this example, a new database is created with a single table
 * that has an index.  Ten rows are inserted in random order.
 * Finally all the data is read from the database using the index to order
 * the results.
 * 
 * The following methods are illustrated:
 *     Raima.Rdm.RdmConnection:
 *         Close() Method
 *         CreateCommand() Method
 *         Open() Method
 *         RdmConnection(String) Constructor
 *     Raima.Rdm.RdmCommand:
 *         CommandText Property
 *         ExecuteNonQuery() Method
 *         ExecuteReader() Method
 *     Raima.Rdm.RdmDataReader:
 *         Item[int] Property
 *         Read() Method
 * 
 * They are fully document in http://docs.raima.com/rdm/.
 * 
 * For simplicity this example does not catch any thrown exceptions
 * but good programming practices would dictate that this occur in
 * a full application.
 *)

let CreateDatabase =
    let conn = new RdmConnection("host=local")
    conn.Open()

    let cmd = conn.CreateCommand()

    (* Attempt to drop the database.  If the database does not already exist
     * this will fail and we simply ignore the failure for this sample. *)
    try
        [|
            "DROP DATABASE SQL04";
            "COMMIT"
        |] |>
            Array.iter(fun c ->
                cmd.CommandText <- c
                cmd.ExecuteNonQuery() |> ignore
            )
    with
        | exn -> ()

    (* Attempt to create the database *)
    [|
        "CREATE DATABASE SQL04";
        "CREATE TABLE IndTab (id INTEGER PRIMARY KEY)";
        "COMMIT"
    |] |>
        Array.iter(fun c ->
            cmd.CommandText <- c
            cmd.ExecuteNonQuery() |> ignore
        )

    conn.Close()

CreateDatabase

(* Create the connection with a simple connection string *)
let conn = new RdmConnection("host=local;database=SQL04;openmode=x")

(* Open the connection to the database *)
conn.Open()

(* Create a new command *)
let cmd = conn.CreateCommand()
let rand = new System.Random(1)

(* Insert ten rows into the table with random data *)
[1..10] |>
    List.map(fun ii -> rand.Next() % 100) |>
    List.iter(fun ii ->
        cmd.CommandText <- "INSERT INTO IndTab VALUES " + (string ii)
        cmd.ExecuteNonQuery() |> ignore
    )

(* Scan through all the existing rows using the index for order *)
cmd.CommandText <- "SELECT id FROM IndTab order by id"
let reader = cmd.ExecuteReader()

while (reader.Read()) do
    printfn "%s" (string (reader.Item(0)))

conn.Close()

printfn "Hit <Enter> to continue"
System.Console.ReadLine() |> ignore

